Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(273)

Unified Diff: webrtc/modules/audio_coding/codecs/isac/main/interface/isac.h

Issue 1225093005: Split iSAC encoder/decoder: Test more cases (and make sure they work) (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Don't use std::initializer_list Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/audio_coding/codecs/isac/main/interface/isac.h
diff --git a/webrtc/modules/audio_coding/codecs/isac/main/interface/isac.h b/webrtc/modules/audio_coding/codecs/isac/main/interface/isac.h
index 1fe11bcef03c45915b73f4d5f0d4285378e2f4c4..cdc491f361854ae56934b29d1cf420df45bd54e9 100644
--- a/webrtc/modules/audio_coding/codecs/isac/main/interface/isac.h
+++ b/webrtc/modules/audio_coding/codecs/isac/main/interface/isac.h
@@ -269,6 +269,8 @@ extern "C" {
int32_t rate,
int framesize);
+ void WebRtcIsac_SetInitialBweBottleneck(ISACStruct* ISAC_main_inst,
+ int bottleneck_bits_per_second);
/******************************************************************************
* WebRtcIsac_ControlBwe(...)
@@ -706,13 +708,18 @@ extern "C" {
int16_t* decoded,
int16_t* speechType);
/* Fills in an IsacBandwidthInfo struct. */
Jelena 2015/07/10 05:18:46 maybe: |inst| instead of inst. I have seen it used
kwiberg-webrtc 2015/07/15 00:24:49 Done.
void WebRtcIsac_GetBandwidthInfo(ISACStruct* inst, IsacBandwidthInfo* bwinfo);
- /* Uses the values from an IsacBandwidthInfo struct. */
+ /* Uses the values from an IsacBandwidthInfo struct. inst should be an
+ encoder. */
void WebRtcIsac_SetBandwidthInfo(ISACStruct* inst,
const IsacBandwidthInfo* bwinfo);
+ /* If inst is a decoder but not an encoder: tell it what sample rate the
+ encoder is using, for bandwidth estimation purposes. */
+ void WebRtcIsac_SetEncSampRateInDecoder(ISACStruct* inst, int sample_rate_hz);
+
#if defined(__cplusplus)
}
#endif
@@ -706,13 +708,18 @@ extern "C" {
int16_t* decoded,
int16_t* speechType);
- /* Fills in an IsacBandwidthInfo struct. */
+ /* Fills in an IsacBandwidthInfo struct. inst should be a decoder. */
Jelena 2015/07/10 05:18:46 maybe: |inst| instead of inst. I have seen it used
kwiberg-webrtc 2015/07/15 00:24:49 Done.

Powered by Google App Engine
This is Rietveld 408576698